@@ -1,4 +1,4 @@
-from main import hash_api_key, verify_api_key
+from akms_hash.main import hash_api_key, verify_api_key
 
 __all__ = [
     hash_api_key,
