@@ -2,9 +2,13 @@ import hashlib
 import os
 
 
+def __hash_api_key(api_key: str, salt: bytes) -> bytes:
+    return hashlib.pbkdf2_hmac("sha256", api_key.encode("utf-8"), salt, 100000)
+
+
 def hash_api_key(api_key: str) -> bytes:
     salt = os.urandom(32)
-    key = hashlib.pbkdf2_hmac("sha256", api_key.encode("utf-8"), salt, 100000)
+    key = __hash_api_key(api_key, salt)
 
     storage = salt + key
 
@@ -23,6 +27,6 @@ def verify_api_key(storage: str, api_key: str) -> bool:
     salt = __get_salt_from_storage(storage)
     hashed_api_key = __get_hashed_api_key_from_storage(storage)
 
-    received_hashed_api_key = hashlib.pbkdf2_hmac("sha256", api_key.encode("utf-8"), salt, 100000)
+    received_hashed_api_key = __hash_api_key(api_key, salt)
 
     return hashed_api_key == received_hashed_api_key
